@@ -1,4 +1,4 @@
-# last modified 12 Dec 04 by J. Fox
+# last modified 19 Oct 06 by J. Fox
 
 "polyserial" <-
 function(x, y, ML=FALSE, control=list(), std.err=FALSE, maxcor=.9999, bins=4){
@@ -19,6 +19,7 @@ function(x, y, ML=FALSE, control=list(), std.err=FALSE, maxcor=.9999, bins=4){
   tab <- table(y)
   n <- sum(tab)
   s <- length(tab)
+  if (s < 2) stop("y has fewer than 2 levels")
   indices <- 1:n
   cuts <- qnorm(cumsum(tab)/n)[-s]
   y <- as.numeric(as.factor(y))
